@@ -1,11 +1,11 @@
-use ansiterm::{ANSIString, Style};
+use nu_ansi_term::{AnsiString as ANSIString, Style};
 
 use crate::fs::fields as f;
 
-
 impl f::Type {
     pub fn render<C: Colours>(self, colours: &C) -> ANSIString<'static> {
-        match self {
+        #[rustfmt::skip]
+        return match self {
             Self::File         => colours.normal().paint("."),
             Self::Directory    => colours.directory().paint("d"),
             Self::Pipe         => colours.pipe().paint("|"),
@@ -14,11 +14,10 @@ impl f::Type {
             Self::CharDevice   => colours.char_device().paint("c"),
             Self::Socket       => colours.socket().paint("s"),
             Self::Special      => colours.special().paint("?"),
-        }
+        };
     }
 }
 
-
 pub trait Colours {
     fn normal(&self) -> Style;
     fn directory(&self) -> Style;
