@@ -1,5 +1,5 @@
-use ansiterm::Style;
 use locale::Numeric as NumericLocale;
+use nu_ansi_term::Style;
 use number_prefix::Prefix;
 
 use crate::fs::fields as f;
@@ -23,7 +23,6 @@ impl f::Size {
             Self::DeviceIDs(ref ids) => return ids.render(colours),
         };
 
-        let gradient_style = colours.major();
         let is_gradient_mode =
             color_scale_info.is_some_and(|csi| csi.options.mode == ColorScaleMode::Gradient);
 
@@ -44,7 +43,7 @@ impl f::Size {
                 return if is_gradient_mode {
                     let csi = color_scale_info.unwrap();
                     TextCell::paint(
-                        csi.adjust_style(gradient_style, size as f32, csi.size),
+                        csi.adjust_style(colours.size(prefix), size as f32, csi.size),
                         string,
                     )
                 } else {
@@ -59,7 +58,7 @@ impl f::Size {
                 return if is_gradient_mode {
                     let csi = color_scale_info.unwrap();
                     TextCell::paint(
-                        csi.adjust_style(gradient_style, size as f32, csi.size),
+                        csi.adjust_style(colours.size(None), size as f32, csi.size),
                         numerics.format_int(b),
                     )
                 } else {
@@ -82,9 +81,9 @@ impl f::Size {
             contents: if is_gradient_mode {
                 let csi = color_scale_info.unwrap();
                 vec![
-                    csi.adjust_style(gradient_style, size as f32, csi.size)
+                    csi.adjust_style(colours.size(Some(prefix)), size as f32, csi.size)
                         .paint(number),
-                    csi.adjust_style(gradient_style, size as f32, csi.size)
+                    csi.adjust_style(colours.size(Some(prefix)), size as f32, csi.size)
                         .paint(symbol),
                 ]
             } else {
@@ -132,9 +131,9 @@ pub mod test {
     use crate::output::cell::{DisplayWidth, TextCell};
     use crate::output::table::SizeFormat;
 
-    use ansiterm::Colour::*;
-    use ansiterm::Style;
     use locale::Numeric as NumericLocale;
+    use nu_ansi_term::Color::*;
+    use nu_ansi_term::Style;
     use number_prefix::Prefix;
 
     struct TestColours;
@@ -162,7 +161,7 @@ pub mod test {
                 &NumericLocale::english(),
                 None
             )
-        )
+        );
     }
 
     #[test]
@@ -181,7 +180,7 @@ pub mod test {
                 &NumericLocale::english(),
                 None
             )
-        )
+        );
     }
 
     #[test]
@@ -200,7 +199,7 @@ pub mod test {
                 &NumericLocale::english(),
                 None
             )
-        )
+        );
     }
 
     #[test]
@@ -219,7 +218,7 @@ pub mod test {
                 &NumericLocale::english(),
                 None
             )
-        )
+        );
     }
 
     #[test]
@@ -246,6 +245,6 @@ pub mod test {
                 &NumericLocale::english(),
                 None
             )
-        )
+        );
     }
 }
